% Auto-generated chapter 45 for malik
% Hadiths in this chapter: 25

\hadithdefcmd{malik}{1598}{وَحَدَّثَنِي يَحْيَى بْنُ يَحْيَى، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ الأَنْصَارِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ فِي مِكْيَالِهِمْ وَبَارِكْ لَهُمْ فِي صَاعِهِمْ وَمُدِّهِمْ ‏"‏ ‏.‏ يَعْنِي أَهْلَ الْمَدِينَةِ ‏.‏\hadithno{1598}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{1599}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ كَانَ النَّاسُ إِذَا رَأَوْا أَوَّلَ الثَّمَرِ جَاءُوا بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا أَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَنَا فِي ثَمَرِنَا وَبَارِكْ لَنَا فِي مَدِينَتِنَا وَبَارِكْ لَنَا فِي صَاعِنَا وَبَارِكْ لَنَا فِي مُدِّنَا اللَّهُمَّ إِنَّ إِبْرَاهِيمَ عَبْدُكَ وَخَلِيلُكَ وَنَبِيُّكَ وَإِنِّي عَبْدُكَ وَنَبِيُّكَ وَإِنَّهُ دَعَاكَ لِمَكَّةَ وَإِنِّي أَدْعُوكَ لِلْمَدِينَةِ بِمِثْلِ مَا دَعَاكَ بِهِ لِمَكَّةَ وَمِثْلِهِ مَعَهُ ‏"‏ ‏.‏ ثُمَّ يَدْعُو أَصْغَرَ وَلِيدٍ يَرَاهُ فَيُعْطِيهِ ذَلِكَ الثَّمَرَ ‏.‏\hadithno{1599}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih from his father that Abu Hurayra said, "When people saw the first fruits of the season, they brought them to the Messenger of Allah, may Allah bless him and grant him peace. The Messenger of Allah, may Allah bless him and grant him peace, took them and said, 'O Allah! Bless us in our fruits. Bless us in our city. Bless us in our sa and bless us in our mudd. O Allah! Ibrahim is Your slave, Your Khalil and Your Prophet. I am Your slave and Your Prophet. He prayed to You for Makka. I pray to You for Madina for the like of what He prayed to You for Makka, and the like of it with it.' Then he called the smallest child he saw and gave him the fruits}}
\hadithdefcmd{malik}{1600}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ قَطَنِ بْنِ وَهْبِ بْنِ عُمَيْرِ بْنِ الأَجْدَعِ، أَنْ يُحَنَّسَ، مَوْلَى الزُّبَيْرِ بْنِ الْعَوَّامِ أَخْبَرَهُ أَنَّهُ، كَانَ جَالِسًا عِنْدَ عَبْدِ اللَّهِ بْنِ عُمَرَ فِي الْفِتْنَةِ فَأَتَتْهُ مَوْلاَةٌ لَهُ تُسَلِّمُ عَلَيْهِ فَقَالَتْ إِنِّي أَرَدْتُ الْخُرُوجَ يَا أَبَا عَبْدِ الرَّحْمَنِ اشْتَدَّ عَلَيْنَا الزَّمَانُ ‏.‏ فَقَالَ لَهَا عَبْدُ اللَّهِ بْنُ عُمَرَ اقْعُدِي لُكَعُ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَصْبِرُ عَلَى لأْوَائِهَا وَشِدَّتِهَا أَحَدٌ إِلاَّ كُنْتُ لَهُ شَفِيعًا أَوْ شَهِيدًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1600}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Qatan ibn Wahb ibn Umayr ibn al-Ajda that Yuhannas, the mawla of az-Zubayr ibn al-Awwam informed him that he was sitting with Abdullah ibn Umar during the troubles (at the time of al-Hajaj ibn Yusuf) . A female mawla of his came and greeted him. She said, "I want to leave, Abu Abd ar-Rahman. The time is harsh for us." Abdullah ibn Umar said to her, "Sit down, O you with little knowledge, for I have heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'No one will be patient in hunger and hardship in it (Madina) except that I will be a witness or intercede for him on the Day of Rising}}
\hadithdefcmd{malik}{1601}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ أَعْرَابِيًّا، بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الإِسْلاَمِ فَأَصَابَ الأَعْرَابِيَّ وَعْكٌ بِالْمَدِينَةِ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى فَخَرَجَ الأَعْرَابِيُّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْمَدِينَةُ كَالْكِيرِ تَنْفِي خَبَثَهَا وَيَنْصَعُ طِيبُهَا ‏"‏ ‏.‏\hadithno{1601}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn al-Munkadir from Jabir ibn Abdullah that a Bedouin took an oath of allegiance in Islam with the Messenger of Allah, may Allah bless him and grant him peace. A fever befell the Bedouin at Madina. He came to the Messenger of Allah, and said, "Messenger of Allah, release me from my pledge." The Messenger of Allah, may Allah bless him and grant him peace, refused. Then he came to him again and said, "Release me from my pledge." The Messenger of Allah may Allah bless him and grant him peace, refused. Then he came again and said, "Release me from my pledge." He refused. Then he came again and said, "Release me from my pledge." He refused. The Bedouin left and the Messenger of Allah, may Allah bless him and grant him peace, said, "Madina is like the blacksmith's furnace. It removes the impurities and purifies the good}}
\hadithdefcmd{malik}{1602}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سَمِعْتُ أَبَا الْحُبَابِ، سَعِيدَ بْنَ يَسَارٍ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أُمِرْتُ بِقَرْيَةٍ تَأْكُلُ الْقُرَى يَقُولُونَ يَثْرِبُ ‏.‏ وَهِيَ الْمَدِينَةُ تَنْفِي النَّاسَ كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ ‏"‏ ‏.‏\hadithno{1602}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me that Yahya ibn Said said, "I heard Abu'l-Hubab Said ibn Yasar say that he heard Abu Hurayra say that he heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'I was ordered to a town which will eat up towns. They used to say, 'Yathrib,' but it is Madina. It removes the bad people like the blacksmith's furnace removes impurities from the iron}}
\hadithdefcmd{malik}{1603}{وَحَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْرُجُ أَحَدٌ مِنَ الْمَدِينَةِ رَغْبَةً عَنْهَا إِلاَّ أَبْدَلَهَا اللَّهُ خَيْرًا مِنْهُ ‏"‏ ‏.‏\hadithno{1603}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "No one leaves Madina preferring to live elsewhere, but that Allah will give it better than him in place of him}}
\hadithdefcmd{malik}{1604}{وَحَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ سُفْيَانَ بْنِ أَبِي زُهَيْرٍ، أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تُفْتَحُ الْيَمَنُ فَيَأْتِي قَوْمٌ يَبِسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ وَتُفْتَحُ الشَّامُ فَيَأْتِي قَوْمٌ يَبِسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ وَتُفْتَحُ الْعِرَاقُ فَيَأْتِي قَوْمٌ يَبِسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ‏"‏ ‏.‏\hadithno{1604}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father from Abdullah ibn az-Zubayr that Sufyan ibn Abi Zuhayr said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'Yemen will be conquered and the people will be attracted to it, taking their families and whoever obeys them. Madina would have been better for them, had they but known. Ash-Sham will be conquered and people will be attracted to it, taking their families and whoever obeys them. Madina would have been better for them, had they but known. Iraq will be conquered and people will be attracted to it, taking their families and whoever obeys them. Madina would have been better for them, had they but known}}
\hadithdefcmd{malik}{1605}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ حِمَاسٍ، عَنْ عَمِّهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَتُتْرَكَنَّ الْمَدِينَةُ عَلَى أَحْسَنِ مَا كَانَتْ حَتَّى يَدْخُلَ الْكَلْبُ أَوِ الذِّئْبُ فَيُغَذِّي عَلَى بَعْضِ سَوَارِي الْمَسْجِدِ أَوْ عَلَى الْمِنْبَرِ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ فَلِمَنْ تَكُونُ الثِّمَارُ ذَلِكَ الزَّمَانَ قَالَ ‏"‏ لِلْعَوَافِي الطَّيْرِ وَالسِّبَاعِ ‏"‏ ‏.‏\hadithno{1605}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Ibn Himas from his paternal uncle from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Madina will be left in the best way that it is until a dog or wolf enters it and urinates on one of the pillars of the mosque or on the mimbar." They asked, "Messenger of Allah! Who will have the fruit at that time?" He replied, "Animals seeking food, birds and wild beasts}}
\hadithdefcmd{malik}{1606}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، حِينَ خَرَجَ مِنَ الْمَدِينَةِ الْتَفَتَ إِلَيْهَا فَبَكَى ثُمَّ قَالَ يَا مُزَاحِمُ أَتَخْشَى أَنْ نَكُونَ مِمَّنْ نَفَتِ الْمَدِينَةُ\hadithno{1606}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik related to me that he had heard that when Umar ibn Abd al- Aziz left Madina, he turned towards it and wept. Then he said, "O Muzahim! Do you fear that we might be among those that Madina casts off?}}
\hadithdefcmd{malik}{1607}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَمْرٍو، مَوْلَى الْمُطَّلِبِ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَلَعَ لَهُ أُحُدٌ فَقَالَ ‏ "‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ اللَّهُمَّ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ وَأَنَا أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا ‏"‏ ‏.‏\hadithno{1607}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Amr, the mawla of al-Muttalib from Anas ibn Malik that the Messenger of Allah, may Allah bless him and grant him peace, saw Uhud and said, "This is a mountain which loves us and we love it. O Allah! Ibrahim made Makka Haram, and I will make what is between the two tracts of black stones (in Madina) a Haram}}
\hadithdefcmd{malik}{1608}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ لَوْ رَأَيْتُ الظِّبَاءَ بِالْمَدِينَةِ تَرْتَعُ مَا ذَعَرْتُهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا بَيْنَ لاَبَتَيْهَا حَرَامٌ ‏"‏ ‏.‏\hadithno{1608}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Said ibn al-Musayyab that Abu Hurayra said, "Had I seen a gazelle at Madina, I would have left it to graze and would not have frightened it. The Messenger of Allah, may Allah bless him and grant him peace, said, 'What is between the two tracts of black stones is a Haram}}
\hadithdefcmd{malik}{1609}{وَحَدَّثَنِي مَالِكٌ، عَنْ يُونُسَ بْنِ يُوسُفَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، أَنَّهُ وَجَدَ غِلْمَانًا قَدْ أَلْجَئُوا ثَعْلَبًا إِلَى زَاوِيَةٍ فَطَرَدَهُمْ عَنْهُ ‏.‏ قَالَ مَالِكٌ لاَ أَعْلَمُ إِلاَّ أَنَّهُ قَالَ أَفِي حَرَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم يُصْنَعُ هَذَا\hadithno{1609}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Yunus ibn Yusuf from Ata ibn Yasar that Abu Ayyub al-Ansari found some boys who had driven a fox into a corner, and he chased them away from it. Malik said, "I only know that he said, 'Is this done in the Haram of the Messenger of Allah, may Allah bless him and grant him peace?}}
\hadithdefcmd{malik}{1610}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ رَجُلٍ، قَالَ دَخَلَ عَلَىَّ زَيْدُ بْنُ ثَابِتٍ وَأَنَا بِالأَسْوَافِ، قَدِ اصْطَدْتُ نُهَسًا فَأَخَذَهُ مِنْ يَدِي فَأَرْسَلَهُ ‏.‏\hadithno{1610}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from a man who said, "Zayd ibn Thabit came across me while I was at al-Aswaf (on the outskirts of Madina). I had captured a hawk. He took it from my hands and set it free}}
\hadithdefcmd{malik}{1611}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وُعِكَ أَبُو بَكْرٍ وَبِلاَلٌ - قَالَتْ - فَدَخَلْتُ عَلَيْهِمَا فَقُلْتُ يَا أَبَتِ كَيْفَ تَجِدُكَ وَيَا بِلاَلُ كَيْفَ تَجِدُكَ قَالَتْ فَكَانَ أَبُو بَكْرٍ إِذَا أَخَذَتْهُ الْحُمَّى يَقُولُ كُلُّ امْرِئٍ مُصَبَّحٌ فِي أَهْلِهِ وَالْمَوْتُ أَدْنَى مِنْ شِرَاكِ نَعْلِهِ وَكَانَ بِلاَلٌ إِذَا أُقْلِعَ عَنْهُ يَرْفَعُ عَقِيرَتَهُ فَيَقُولُ أَلاَ لَيْتَ شِعْرِي هَلْ أَبِيتَنَّ لَيْلَةً بِوَادٍ وَحَوْلِي إِذْخِرٌ وَجَلِيلُ وَهَلْ أَرِدَنْ يَوْمًا مِيَاهَ مَجَنَّةٍ وَهَلْ يَبْدُوَنْ لِي شَامَةٌ وَطَفِيلُ قَالَتْ عَائِشَةُ فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏ "‏ اللَّهُمَّ حَبِّبْ إِلَيْنَا الْمَدِينَةَ كَحُبِّنَا مَكَّةَ أَوْ أَشَدَّ وَصَحِّحْهَا وَبَارِكْ لَنَا فِي صَاعِهَا وَمُدِّهَا وَانْقُلْ حُمَّاهَا فَاجْعَلْهَا بِالْجُحْفَةِ ‏"‏ ‏.‏\hadithno{1611}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, umm al-muminin said, "When the Messenger of Allah, may Allah bless him and grant him peace, came to Madina, Abu Bakr and Bilal came down with a fever. I visited them and said, 'Father, how are you? Bilal, how are you?'" She continued, "When Abu Bakr's fever worsened he would say, 'Every man is struck down among his people in the morning - death is nearer than the strap of his sandal.'" When it left Bilal, he raised his voice and said, 'Would that I knew whether I will spend a night at the valley of Makka with the idhkhir herb and jalil herb around me. Will I go one day to the waters of Majinna? Will the mountains of Shama and Tafil appear to me?' " ' A'isha continued, "I went to the Messenger of Allah, may Allah bless him and grant him peace, and informed him. He said, 'O Allah! Make us love Madina as much as we love Makka or even more. Make it sound and bless us in our sa and mudd. Remove its fever and put it in al-Juhfa}}
\hadithdefcmd{malik}{1612}{قَالَ مَالِكٌ وَحَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، أَنَّ عَائِشَةَ، قَالَتْ وَكَانَ عَامِرُ بْنُ فُهَيْرَةَ يَقُولُ قَدْ رَأَيْتُ الْمَوْتَ قَبْلَ ذَوْقِهِ إِنَّ الْجَبَانَ حَتْفُهُ مِنْ فَوْقِهِ ‏.‏\hadithno{1612}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said that Yahya ibn Said had related to him that A'isha said that Amir ibn Fuhayra had said at the time of the epidemic, "I have seen death before tasting it, the coward's destination is from above him}}
\hadithdefcmd{malik}{1613}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَلَى أَنْقَابِ الْمَدِينَةِ مَلاَئِكَةٌ لاَ يَدْخُلُهَا الطَّاعُونُ وَلاَ الدَّجَّالُ\hadithno{1613}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nuaym ibn Abdullah al-Mujmir that Abu Hurayra said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'There are angels at the entries of Madina, and neither plague nor the Dajjal will enter it}}
\hadithdefcmd{malik}{1614}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، أَنَّهُ سَمِعَ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، يَقُولُ كَانَ مِنْ آخِرِ مَا تَكَلَّمَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ قَالَ ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ وَالنَّصَارَى اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ لاَ يَبْقَيَنَّ دِينَانِ بِأَرْضِ الْعَرَبِ ‏"‏ ‏.‏\hadithno{1614}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ismail ibn Abi Hakim that he heard Umar ibn Abd al-Aziz say, "One of the last things that the Messenger of Allah, may Allah bless him and grant him peace, said was, 'May Allah fight the jews and the christians. They took the graves of their Prophets as places of prostration . Two deens shall not co-exist in the land of the Arabs}}
\hadithdefcmd{malik}{1615}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَجْتَمِعُ دِينَانِ فِي جَزِيرَةِ الْعَرَبِ ‏"‏ ‏.‏ قَالَ مَالِكٌ قَالَ ابْنُ شِهَابٍ فَفَحَصَ عَنْ ذَلِكَ عُمَرُ بْنُ الْخَطَّابِ حَتَّى أَتَاهُ الثَّلْجُ وَالْيَقِينُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَجْتَمِعُ دِينَانِ فِي جَزِيرَةِ الْعَرَبِ ‏"‏ فَأَجْلَى يَهُودَ خَيْبَرَ ‏.‏ قَالَ مَالِكٌ وَقَدْ أَجْلَى عُمَرُ بْنُ الْخَطَّابِ يَهُودَ نَجْرَانَ وَفَدَكَ فَأَمَّا يَهُودُ خَيْبَرَ فَخَرَجُوا مِنْهَا لَيْسَ لَهُمْ مِنَ الثَّمَرِ وَلاَ مِنَ الأَرْضِ شَىْءٌ وَأَمَّا يَهُودُ فَدَكَ فَكَانَ لَهُمْ نِصْفُ الثَّمَرِ وَنِصْفُ الأَرْضِ لأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ صَالَحَهُمْ عَلَى نِصْفِ الثَّمَرِ وَنِصْفِ الأَرْضِ فَأَقَامَ لَهُمْ عُمَرُ نِصْفَ الثَّمَرِ وَنِصْفَ الأَرْضِ قِيمَةً مِنْ ذَهَبٍ وَوَرِقٍ وَإِبِلٍ وَحِبَالٍ وَأَقْتَابٍ ثُمَّ أَعْطَاهُمُ الْقِيمَةَ وَأَجْلاَهُمْ مِنْهَا ‏.‏\hadithno{1615}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that the Messenger of Allah, may Allah bless him and grant him peace, said, "Two deens shall not co-exist in the Arabian Peninsula." Malik said that Ibn Shihab said, ''Umar ibn al-Khattab searched for information about that until he was absolutely convinced that the Messenger of Allah, may Allah bless him and grant him peace, had said, 'Two deens shall not co-exist in the Arabian Peninsula,' and he therefore expelled the jews from Khaybar." Malik said, ''Umar ibn al-Khattab expelled the jews from Najran (a jewish settlement in the Yemen) and Fadak (a jewish settlement thirty miles from Madina). When the jews of Khaybar left, they did not take any fruit or land. The jews of Fadak took half the fruit and half the land, because the Messenger of Allah, may Allah bless him and grant him peace, had made a settlement with them for that. So Umar entrusted to them the value in gold, silver, camels, ropes and saddle bags of half the fruit and half the land, and handed the value over to them and expelled them}}
\hadithdefcmd{malik}{1616}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَلَعَ لَهُ أُحُدٌ فَقَالَ ‏ "‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏ ‏.‏\hadithno{1616}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, came in view of Uhud and said, "This is a mountain which loves us and we love it}}
\hadithdefcmd{malik}{1617}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، أَنَّ أَسْلَمَ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ أَخْبَرَهُ أَنَّهُ، زَارَ عَبْدَ اللَّهِ بْنَ عَيَّاشٍ الْمَخْزُومِيَّ فَرَأَى عِنْدَهُ نَبِيذًا وَهُوَ بِطَرِيقِ مَكَّةَ فَقَالَ لَهُ أَسْلَمُ إِنَّ هَذَا الشَّرَابَ يُحِبُّهُ عُمَرُ بْنُ الْخَطَّابِ فَحَمَلَ عَبْدُ اللَّهِ بْنُ عَيَّاشٍ قَدَحًا عَظِيمًا فَجَاءَ بِهِ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَوَضَعَهُ فِي يَدَيْهِ فَقَرَّبَهُ عُمَرُ إِلَى فِيهِ ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ عُمَرُ إِنَّ هَذَا لَشَرَابٌ طَيِّبٌ فَشَرِبَ مِنْهُ ثُمَّ نَاوَلَهُ رَجُلاً عَنْ يَمِينِهِ ‏.‏ فَلَمَّا أَدْبَرَ عَبْدُ اللَّهِ نَادَاهُ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ أَأَنْتَ الْقَائِلُ لَمَكَّةُ خَيْرٌ مِنَ الْمَدِينَةِ فَقَالَ عَبْدُ اللَّهِ فَقُلْتُ هِيَ حَرَمُ اللَّهِ وَأَمْنُهُ وَفِيهَا بَيْتُهُ ‏.‏ فَقَالَ عُمَرُ لاَ أَقُولُ فِي بَيْتِ اللَّهِ وَلاَ فِي حَرَمِهِ شَيْئًا ‏.‏ ثُمَّ قَالَ عُمَرُ أَأَنْتَ الْقَائِلُ لَمَكَّةُ خَيْرٌ مِنَ الْمَدِينَةِ قَالَ فَقُلْتُ هِيَ حَرَمُ اللَّهِ وَأَمْنُهُ وَفِيهَا بَيْتُهُ ‏.‏ فَقَالَ عُمَرُ لاَ أَقُولُ فِي حَرَمِ اللَّهِ وَلاَ فِي بَيْتِهِ شَيْئًا ثُمَّ انْصَرَفَ ‏.‏\hadithno{1617}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abd ar- Rahman ibn al-Qasim that Aslam, the mawla of Umar ibn al-Khattab informed him that he had visited Abdullah ibn Ayyash al-Makhzumi. He saw that he had some nabidh with him and he was at that moment on the way to Makka. Aslam said to him, ''Umar ibn al-Khattab loves this drink." Abdullah ibn Ayyash therefore carried a great drinking bowl and brought it to Umar ibn al-Khattab and placed it before him. Umar brought it near to him and then raised his head. Umar said, "This drink is good," so he drank some of it and then passed it to a man on his right. When Abdullah turned to go, Umar ibn al-Khattab called him and asked, "Are you the person who says that Makka is better than Madina?" Abdullah said, "I said that it was the Haram of Allah, and His place of security, and His House was in it." Umar said, "I am not saying anything about the House of Allah or His Haram." Then Umar repeated "Are you the person who says that Makka is better than Madina?" He replied, "I said that it was the Haram of Allah and His place of security, and His House was in it." Umar said, "I am not saying anything about the House of Allah and His Haram." Then Abdullah left}}
\hadithdefcmd{malik}{1618}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَرَجَ إِلَى الشَّامِ حَتَّى إِذَا كَانَ بِسَرْغَ لَقِيَهُ أُمَرَاءُ الأَجْنَادِ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ وَأَصْحَابُهُ فَأَخْبَرُوهُ أَنَّ الْوَبَأَ قَدْ وَقَعَ بِأَرْضِ الشَّامِ قَالَ ابْنُ عَبَّاسٍ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ادْعُ لِي الْمُهَاجِرِينَ الأَوَّلِينَ ‏.‏ فَدَعَاهُمْ فَاسْتَشَارَهُمْ وَأَخْبَرَهُمْ أَنَّ الْوَبَأَ قَدْ وَقَعَ بِالشَّامِ فَاخْتَلَفُوا فَقَالَ بَعْضُهُمْ قَدْ خَرَجْتَ لأَمْرٍ وَلاَ نَرَى أَنْ تَرْجِعَ عَنْهُ ‏.‏ وَقَالَ بَعْضُهُمْ مَعَكَ بَقِيَّةُ النَّاسِ وَأَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ نَرَى أَنْ تُقْدِمَهُمْ عَلَى هَذَا الْوَبَإِ ‏.‏ فَقَالَ عُمَرُ ارْتَفِعُوا عَنِّي ‏.‏ ثُمَّ قَالَ ادْعُ لِي الأَنْصَارَ فَدَعَوْتُهُمْ فَاسْتَشَارَهُمْ فَسَلَكُوا سَبِيلَ الْمُهَاجِرِينَ وَاخْتَلَفُوا كَاخْتِلاَفِهِمْ فَقَالَ ارْتَفِعُوا عَنِّي ‏.‏ ثُمَّ قَالَ ادْعُ لِي مَنْ كَانَ هَا هُنَا مِنْ مَشْيَخَةِ قُرَيْشٍ مِنْ مُهَاجِرَةِ الْفَتْحِ ‏.‏ فَدَعَوْتُهُمْ فَلَمْ يَخْتَلِفْ عَلَيْهِ مِنْهُمُ اثْنَانِ فَقَالُوا نَرَى أَنْ تَرْجِعَ بِالنَّاسِ وَلاَ تُقْدِمَهُمْ عَلَى هَذَا الْوَبَإِ فَنَادَى عُمَرُ فِي النَّاسِ إِنِّي مُصْبِحٌ عَلَى ظَهْرٍ فَأَصْبِحُوا عَلَيْهِ ‏.‏ فَقَالَ أَبُو عُبَيْدَةَ أَفِرَارًا مِنْ قَدَرِ اللَّهِ فَقَالَ عُمَرُ لَوْ غَيْرُكَ قَالَهَا يَا أَبَا عُبَيْدَةَ نَعَمْ نَفِرُّ مِنْ قَدَرِ اللَّهِ إِلَى قَدَرِ اللَّهِ أَرَأَيْتَ لَوْ كَانَ لَكَ إِبِلٌ فَهَبَطَتْ وَادِيًا لَهُ عُدْوَتَانِ إِحْدَاهُمَا مُخْصِبَةٌ وَالأُخْرَى جَدْبَةٌ أَلَيْسَ إِنْ رَعَيْتَ الْخَصِبَةَ رَعَيْتَهَا بِقَدَرِ اللَّهِ وَإِنْ رَعَيْتَ الْجَدْبَةَ رَعَيْتَهَا بِقَدَرِ اللَّهِ فَجَاءَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ - وَكَانَ غَائِبًا فِي بَعْضِ حَاجَتِهِ - فَقَالَ إِنَّ عِنْدِي مِنْ هَذَا عِلْمًا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏ ‏.‏ قَالَ فَحَمِدَ اللَّهَ عُمَرُ ثُمَّ انْصَرَفَ ‏.‏\hadithno{1618}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abd al-Hamid ibn Abd ar-Rahman ibn Zayd ibn al-Khattab from Abdullah ibn Abdullah ibn al-Harith ibn Nawfal from Abdullah ibn Abbas that Umar ibn al- Khattab set out for ash Sham and when he was at Sargh, near Tabuk, the commanders of the army, Abu Ubayda ibn al-Jarrah and his companions, met him and told him that the plague had broken out in ash-Sham. Ibn Abbas said, "Umar ibn al-Khattab said, 'all the first Muhajir unto me.' He assembled them and asked them for advice, informing them that the plague had broken out in ash Sham. They disagreed. Some said, 'You have set out for something, and we do not think that you should leave it.' Others said, 'You have the companions of the Prophet, may Allah bless him and grant him peace, and the rest of the people with you, and we do not think that you should send them towards this plague.' Umar said, 'Leave me.' Then he said, 'Summon the Ansar to me.' They were summoned and he asked them for advice. They acted as the Muhajirun had and disagreed as they had disagreed. He said, 'Leave me.' "Then he said, 'Summon to me whoever is here of the aged men of Quraysh from the Muhajirun of the conquest.' He summoned them and not one of them differed. They said, 'We think that you should withdraw the people and not send them towards the plague.' Umar called out to the people, 'I am leaving by camel in the morning,' so they set out. Abu Ubayda said, 'Is it flight from the decree of Allah?' Umar said, 'Better that someone other than you had said it, Abu Ubayda. Yes. We flee from the decree of Allah to the decree of Allah. What would you think if these camels had gone down into a valley which had two slopes, one of them fertile, and the other barren. If you pastured in the fertile part, wouldn't you pasture them by the decree of Allah? If you pastured them in the barren part, wouldn't you pasture them by the decree of Allah?' ''Abd ar-Rahman ibn Awf arrived and he had been off doing something and he said, 'I have some knowledge of this. I heard the Messenger of Allah, may Allah bless him and grant him peace, say, "If you hear about it in a land, do not go forward to it. If it comes upon a land and you are in it, then do not depart in flight from it." ' Umar praised Allah and then set off}}
\hadithdefcmd{malik}{1619}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَعَنْ سَالِمٍ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَهُ يَسْأَلُ، أُسَامَةَ بْنَ زَيْدٍ مَا سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الطَّاعُونِ فَقَالَ أُسَامَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الطَّاعُونُ رِجْزٌ أُرْسِلَ عَلَى طَائِفَةٍ مِنْ بَنِي إِسْرَائِيلَ أَوْ عَلَى مَنْ كَانَ قَبْلَكُمْ فَإِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَدْخُلُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏ ‏.‏ قَالَ مَالِكٌ قَالَ أَبُو النَّضْرِ لاَ يُخْرِجُكُمْ إِلاَّ فِرَارٌ مِنْهُ ‏.‏\hadithno{1619}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn al-Munkadir and from Salim ibn Abi'n-Nadr, the mawla of Umar ibn Ubaydullah that Amir ibn Sad ibn Abi Waqqas heard his father ask Usama ibn Zayd, "Have you heard anything from the Messenger of Allah, may Allah bless him and grant him peace, about the plague?" Usama said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'The plague is a punishment that was sent down on a party of the Banu Israil or whoever was before them. When you hear of it in a land, do not enter it. If it comes upon a land and you are in it, do not depart in flight from it.' " Malik said that Abu'n-Nadr said, "That is, do not depart with no other intention but flight}}
\hadithdefcmd{malik}{1620}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَرَجَ إِلَى الشَّامِ فَلَمَّا جَاءَ سَرْغَ بَلَغَهُ أَنَّ الْوَبَأَ قَدْ وَقَعَ بِالشَّامِ فَأَخْبَرَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏ ‏.‏ فَرَجَعَ عُمَرُ بْنُ الْخَطَّابِ مِنْ سَرْغَ ‏.‏\hadithno{1620}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abdullah ibn Amir ibn Rabia that Umar ibn al-Khattab went out to ash-Sham. When he came to Sargh, near Tabuk, he heard that the plague had broken out in ash-Sham. Abd ar-Rahman ibn Awf told him that the Messenger of Allah, may Allah bless him and grant him peace, said, "If you hear that a land has a plague in it, do not go forward to it. If it comes upon a land which you are in, do not depart in flight from it." Umar ibn al- Khattab came back from Sargh}}
\hadithdefcmd{malik}{1621}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، إِنَّمَا رَجَعَ بِالنَّاسِ مِنْ سَرْغَ عَنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، ‏.‏\hadithno{1621}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Umar ibn al-Khattab turned people back at Sargh according to the hadith of Abd ar-Rahman ibn Awf}}
\hadithdefcmd{malik}{1622}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لَبَيْتٌ بِرُكْبَةَ أَحَبُّ إِلَىَّ مِنْ عَشَرَةِ أَبْيَاتٍ بِالشَّامِ ‏.‏ قَالَ مَالِكٌ يُرِيدُ لِطُولِ الأَعْمَارِ وَالْبَقَاءِ وَلِشِدَّةِ الْوَبَإِ بِالشَّامِ ‏.‏\hadithno{1622}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me that Malik said, "I heard that Umar ibn al- Khattab said, 'A night in Rukba (a valley near Taif,) is more preferable to me than ten nights in ash-Sham.' " Malik said, "He meant to lengthen and preserve their lives because of the severity of the plague in ash-Sham}}
